.. Copyright (c) 2016, Johan Mabille, Sylvain Corlay and Wolf Vollprecht

   Distributed under the terms of the BSD 3-Clause License.

   The full license is in the file LICENSE, distributed with this software.

Iterators
=========

In addition to the iterators defined in the different types of expressions, ``xtensor`` provides
classes that allow to iterate over slices of an expression along a specified axis.

.. toctree::

   xaxis_iterator
   xaxis_slice_iterator
